@@ -22,9 +22,10 @@ if (savedData) {
 }
 
 setInterval(function () {
-  // discard any images for tabs that don't exist any more
+  // discard any images for tabs that don't exist any more or that haven't been active recently
   for (var tab in previewCache.images) {
-    if (!tasks.getTaskContainingTab(tab)) {
+    let containingTask = tasks.getTaskContainingTab(tab)
+    if (!containingTask || Date.now() - containingTask.tabs.get(tab).lastActivity > (3 * 24 * 60 * 60 * 1000)) {
       delete previewCache.images[tab]
     }
   }
