@@ -1,3 +1,4 @@
+var webviews = require('webviews.js')
 var browserUI = require('browserUI.js')
 var searchEngine = require('util/searchEngine.js')
 
@@ -197,6 +198,6 @@ var webviewMenu = {
   }
 }
 
-webviews.bindEvent('context-menu', function (e, data) {
+webviews.bindEvent('context-menu', function (webview, tabId, e, data) {
   webviewMenu.showMenu(data)
 })
